==> zio-aws-appmesh_3-5.17.115.1-sources.jar: zio/aws/appmesh/model/CreateRouteRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.appmesh.model.primitives.{AccountId, ResourceName}
import scala.jdk.CollectionConverters.*
final case class CreateRouteRequest(
    clientToken: Option[String] = None,
    meshName: ResourceName,
    meshOwner: Option[AccountId] = None,
    routeName: ResourceName,
    spec: zio.aws.appmesh.model.RouteSpec,
    tags: Option[Iterable[zio.aws.appmesh.model.TagRef]] = None,
    virtualRouterName: ResourceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.CreateRouteRequest = {
    import CreateRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.CreateRouteRequest
      .builder()
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .routeName(ResourceName.unwrap(routeName): java.lang.String)
      .spec(spec.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .virtualRouterName(
        ResourceName.unwrap(virtualRouterName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.CreateRouteRequest.ReadOnly =
    zio.aws.appmesh.model.CreateRouteRequest.wrap(buildAwsValue())
}
object CreateRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.CreateRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.CreateRouteRequest =
      zio.aws.appmesh.model.CreateRouteRequest(
        clientToken.map(value => value),
        meshName,
        meshOwner.map(value => value),
        routeName,
        spec.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        virtualRouterName
      )
    def clientToken: Option[String]
    def meshName: ResourceName
    def meshOwner: Option[AccountId]
    def routeName: ResourceName
    def spec: zio.aws.appmesh.model.RouteSpec.ReadOnly
    def tags: Option[List[zio.aws.appmesh.model.TagRef.ReadOnly]]
    def virtualRouterName: ResourceName
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getRouteName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(routeName)
    def getSpec: ZIO[Any, Nothing, zio.aws.appmesh.model.RouteSpec.ReadOnly] =
      ZIO.succeed(spec)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.appmesh.model.TagRef.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getVirtualRouterName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(virtualRouterName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.CreateRouteRequest
  ) extends zio.aws.appmesh.model.CreateRouteRequest.ReadOnly {
    override val clientToken: Option[String] =
      scala.Option(impl.clientToken()).map(value => value: String)
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Option[AccountId] = scala
      .Option(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val routeName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.routeName())
    override val spec: zio.aws.appmesh.model.RouteSpec.ReadOnly =
      zio.aws.appmesh.model.RouteSpec.wrap(impl.spec())
    override val tags: Option[List[zio.aws.appmesh.model.TagRef.ReadOnly]] =
      scala
        .Option(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.appmesh.model.TagRef.wrap(item)
          }.toList
        )
    override val virtualRouterName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.virtualRouterName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.CreateRouteRequest
  ): zio.aws.appmesh.model.CreateRouteRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-appmesh_3-5.17.206.1-sources.jar: zio/aws/appmesh/model/CreateRouteRequest.scala <==
package zio.aws.appmesh.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.appmesh.model.primitives.{AccountId, ResourceName}
import scala.jdk.CollectionConverters.*
final case class CreateRouteRequest(
    clientToken: Optional[String] = Optional.Absent,
    meshName: ResourceName,
    meshOwner: Optional[AccountId] = Optional.Absent,
    routeName: ResourceName,
    spec: zio.aws.appmesh.model.RouteSpec,
    tags: Optional[Iterable[zio.aws.appmesh.model.TagRef]] = Optional.Absent,
    virtualRouterName: ResourceName
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.appmesh.model.CreateRouteRequest = {
    import CreateRouteRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.appmesh.model.CreateRouteRequest
      .builder()
      .optionallyWith(clientToken.map(value => value: java.lang.String))(
        _.clientToken
      )
      .meshName(ResourceName.unwrap(meshName): java.lang.String)
      .optionallyWith(
        meshOwner.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.meshOwner)
      .routeName(ResourceName.unwrap(routeName): java.lang.String)
      .spec(spec.buildAwsValue())
      .optionallyWith(
        tags.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.tags)
      .virtualRouterName(
        ResourceName.unwrap(virtualRouterName): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.appmesh.model.CreateRouteRequest.ReadOnly =
    zio.aws.appmesh.model.CreateRouteRequest.wrap(buildAwsValue())
}
object CreateRouteRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.appmesh.model.CreateRouteRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.appmesh.model.CreateRouteRequest =
      zio.aws.appmesh.model.CreateRouteRequest(
        clientToken.map(value => value),
        meshName,
        meshOwner.map(value => value),
        routeName,
        spec.asEditable,
        tags.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        virtualRouterName
      )
    def clientToken: Optional[String]
    def meshName: ResourceName
    def meshOwner: Optional[AccountId]
    def routeName: ResourceName
    def spec: zio.aws.appmesh.model.RouteSpec.ReadOnly
    def tags: Optional[List[zio.aws.appmesh.model.TagRef.ReadOnly]]
    def virtualRouterName: ResourceName
    def getClientToken: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("clientToken", clientToken)
    def getMeshName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(meshName)
    def getMeshOwner: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("meshOwner", meshOwner)
    def getRouteName: ZIO[Any, Nothing, ResourceName] = ZIO.succeed(routeName)
    def getSpec: ZIO[Any, Nothing, zio.aws.appmesh.model.RouteSpec.ReadOnly] =
      ZIO.succeed(spec)
    def getTags
        : ZIO[Any, AwsError, List[zio.aws.appmesh.model.TagRef.ReadOnly]] =
      AwsError.unwrapOptionField("tags", tags)
    def getVirtualRouterName: ZIO[Any, Nothing, ResourceName] =
      ZIO.succeed(virtualRouterName)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.appmesh.model.CreateRouteRequest
  ) extends zio.aws.appmesh.model.CreateRouteRequest.ReadOnly {
    override val clientToken: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.clientToken())
      .map(value => value: String)
    override val meshName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.meshName())
    override val meshOwner: Optional[AccountId] = zio.aws.core.internal
      .optionalFromNullable(impl.meshOwner())
      .map(value => zio.aws.appmesh.model.primitives.AccountId(value))
    override val routeName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.routeName())
    override val spec: zio.aws.appmesh.model.RouteSpec.ReadOnly =
      zio.aws.appmesh.model.RouteSpec.wrap(impl.spec())
    override val tags: Optional[List[zio.aws.appmesh.model.TagRef.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tags())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.appmesh.model.TagRef.wrap(item)
          }.toList
        )
    override val virtualRouterName: ResourceName =
      zio.aws.appmesh.model.primitives.ResourceName(impl.virtualRouterName())
  }
  def wrap(
      impl: software.amazon.awssdk.services.appmesh.model.CreateRouteRequest
  ): zio.aws.appmesh.model.CreateRouteRequest.ReadOnly = new Wrapper(impl)
}
